==> haskell-bindings-dsl-1.0.25-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bindings-dsl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bindings-DSL
version:              1.0.25
visibility:           public
id:                   bindings-DSL-1.0.25-7hooPXYlkv21EkqI0QIvf1
key:                  bindings-DSL-1.0.25-7hooPXYlkv21EkqI0QIvf1
license:              BSD-3-Clause
maintainer:           John Wiegley <johnw@newartisans.com>
author:               Maurício C. Antunes
stability:            Stable API, well tested, portable, used in commercial code.
homepage:             https://github.com/jwiegley/bindings-dsl/wiki
synopsis:             FFI domain specific language, on top of hsc2hs.
description:
    This is a set of macros to be used when writing Haskell FFI.
    They were designed to be able to fully describe C interfaces,
    so that hsc2hs can extract from them all Haskell code needed to
    mimic such interfaces. All Haskell names used are automatically
    derived from C names, structures are mapped to Haskell instances
    of Storable, and there are also macros you can use with C code
    to help write bindings to inline functions or macro functions.
    Documentation is available at package homepage:

    <https://github.com/jwiegley/bindings-dsl/wiki>

    The extra module Bindings.Utilities will contain tools that may
    be convenient when working with FFI.

category:             FFI
abi:                  e1b95ad9e65ddcf9feac4514e8f63fbf
exposed:              True
exposed-modules:      Bindings.Utilities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bindings-DSL-1.0.25
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bindings-DSL-1.0.25
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bindings-DSL-1.0.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bindings-dsl
hs-libraries:         HSbindings-DSL-1.0.25-7hooPXYlkv21EkqI0QIvf1
include-dirs:         /usr/lib/ghc-9.4.8/site-local/bindings-DSL-1.0.25/include
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-bindings-dsl/html/bindings-DSL.haddock

haddock-html:         /usr/share/doc/haskell-bindings-dsl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bindings-dsl-1.0.25-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bindings-dsl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bindings-DSL
version:              1.0.25
visibility:           public
id:                   bindings-DSL-1.0.25-8fRfomDUiutCvg6AnZSoGU
key:                  bindings-DSL-1.0.25-8fRfomDUiutCvg6AnZSoGU
license:              BSD-3-Clause
maintainer:           John Wiegley <johnw@newartisans.com>
author:               Maurício C. Antunes
stability:            Stable API, well tested, portable, used in commercial code.
homepage:             https://github.com/jwiegley/bindings-dsl/wiki
synopsis:             FFI domain specific language, on top of hsc2hs.
description:
    This is a set of macros to be used when writing Haskell FFI.
    They were designed to be able to fully describe C interfaces,
    so that hsc2hs can extract from them all Haskell code needed to
    mimic such interfaces. All Haskell names used are automatically
    derived from C names, structures are mapped to Haskell instances
    of Storable, and there are also macros you can use with C code
    to help write bindings to inline functions or macro functions.
    Documentation is available at package homepage:

    <https://github.com/jwiegley/bindings-dsl/wiki>

    The extra module Bindings.Utilities will contain tools that may
    be convenient when working with FFI.

category:             FFI
abi:                  746d45d268716c8bdfb0551fd0785404
exposed:              True
exposed-modules:      Bindings.Utilities
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/bindings-DSL-1.0.25
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/bindings-DSL-1.0.25
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/bindings-DSL-1.0.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bindings-dsl
hs-libraries:         HSbindings-DSL-1.0.25-8fRfomDUiutCvg6AnZSoGU
include-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/bindings-DSL-1.0.25/include

depends:              base-4.18.3.0
haddock-interfaces:
    /usr/share/doc/haskell-bindings-dsl/html/bindings-DSL.haddock

haddock-html:         /usr/share/doc/haskell-bindings-dsl/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
